#ifndef MATRIX3X3_H
#define MATRIX3X3_H
#include "matrixnxn.h"

class Vector;
class Quaternion;

//! 3*3 matrix for rotations
class Matrix3x3 : public MatrixNxN
{
public:
	//! Allocates memory. Values are not initialized.
	Matrix3x3() : MatrixNxN(3) {}

	Matrix3x3( const Matrix3x3 &m );

	//! Calls base constructor, for derived classes.
	Matrix3x3(unsigned long size) : MatrixNxN(size) {}

	Vector operator* (const Vector &v) const;

	//! Creates a rotation matrix from a quaternion
	void setRotation(const Quaternion &orientation);

	//! Creates a rotation matrix: angle yaw around z axis, pitch around y, roll around x
	void setRotation(double yaw, double pitch = 0., double roll = 0.);

	void transpose();

	static Vector multiply(const Matrix3x3 &m, const Vector &v);
	Vector getCol(unsigned long col);
	Vector getRow(unsigned long row);
};

#endif // _MATRIX3X3_H
